/*

This example computes MER-1, MER-2 or MSL areocentric location (r, lon, lat) 
on Mars using only data from SPICE kernels. It also computed az and el
of the Sun as seen from the rover in local level frame.

*/

#include <stdio.h>
#include <string.h>
#include "SpiceUsr.h"

int main( int argc, char * argv[] )
{
  /*
    Constants.
  */
  #define WRDLEN          32

  /*
    Variables.
  */
  SpiceDouble             et;
  SpiceDouble             roverpos[3];
  SpiceDouble             lt;
  SpiceDouble             r;
  SpiceDouble             lon;
  SpiceDouble             lat;
  SpiceDouble             sunpos[3];
  SpiceDouble             az;
  SpiceDouble             el;
  SpiceChar               rover[WRDLEN]; 
  SpiceChar               frame[WRDLEN]; 

  /*
    Get command line. Display usage if it doesn't contain four
    arguments.
  */
  if ( argc != 4 )
  {
    printf ( "\n" );
    printf ( "Usage:\n" );
    printf ( "\n" );
    printf ( "   > rover_example_1 <metakernel> <mer-1|mer-2|msl> <utc>\n" );
    printf ( "\n" );
    printf ( "Use YYYY-MM-DDTHR:MN:SC.### format for input UTC\n" );
    printf ( "\n" );
    return(1);
  }

  /*
    First argument on the command line is the name of a meta-kernel
    file listing SPICE files (kernels) that should be loaded.
  */
  furnsh_c( argv[1] );

  /*
    Second argument is the rover name. Set rover name and local level
    frame names based on it.
  */
  strcpy ( rover, argv[2] );
  strcpy ( frame, argv[2] );
  strcat ( frame, "_local_level" );

  /*
    Third argument is the time provided as a UTC string. Convert it to
    ET.
  */
  str2et_c( argv[3], &et );

  /*
    Compute position of the rover relative to Mars in Mars body-fixed
    frame (IAU_MARS).
  */
  spkpos_c( rover, et, "IAU_MARS", "NONE", "MARS", roverpos, &lt );

  /*
    Convert position to areocentric r, lon, and lat.
  */
  reclat_c( roverpos, &r, &lon, &lat );

  /*
    Print r and lon/lat in degrees.
  */  
  printf ( "\n" );
  printf ( "   r = %12.6f (km)\n",  r );
  printf ( " lon = %12.6f (deg)\n", lon*dpr_c() );
  printf ( " lat = %12.6f (deg)\n", lat*dpr_c() );

  /*
    Compute position of the Sun relative to rover in local-level frame.
  */
  spkpos_c( "SUN", et, frame, "LT+S", rover, sunpos, &lt );

  /*
    Convert position to r, az, and el.
  */
  reclat_c( sunpos, &r, &az, &el );

  /*
    Print az/el in degrees.
  */  
  printf ( "\n" );
  printf ( "  az = %12.6f (deg)\n", az*dpr_c() );
  printf ( "  el = %12.6f (deg)\n", el*dpr_c() );
  printf ( "\n" );

  /*
    All done.
  */
  return(0);

}
