/*

This example computes MER-1, MER-2, or MSL areocentric location (r, lon, lat) 
on Mars using landing site location from SPICE kernels and rover location
relative to the landing site w.r.t. local level frame provided on the
command line.

*/

#include <stdio.h>
#include <string.h>
#include "SpiceUsr.h"

int main( int argc, char * argv[] )
{
  /*
    Constants.
  */
  #define WRDLEN          32

  /*
    Variables.
  */
  SpiceDouble             et;
  SpiceDouble             sitepos[3];
  SpiceDouble             localpos[3];
  SpiceDouble             tmpvec[3];
  SpiceDouble             roverpos[3];
  SpiceDouble             mat[3][3];
  SpiceDouble             lt;
  SpiceDouble             r;
  SpiceDouble             lon;
  SpiceDouble             lat;
  SpiceChar               lsite[WRDLEN]; 
  SpiceChar               frame[WRDLEN]; 

  /*
    Get command line. Display usage if it doesn't contain four
    arguments.
  */
  if ( argc != 7 )
  {
    printf ( "\n" );
    printf ( "Usage:\n" );
    printf ( "\n" );
    printf ( "   > rover_example_2 <metakernel> <mer-1|mer-2|msl> <utc> <x> <y> <z>\n" );
    printf ( "\n" );
    printf ( "Use YYYY-MM-DDTHR:MN:SC.### format for input UTC\n" );
    printf ( "\n" );
    return(1);
  }

  /*
    First argument on the command line is the name of a meta-kernel
    file listing SPICE files (kernels) that should be loaded.
  */
  furnsh_c( argv[1] );

  /*
    Second argument is the rover name. Set landing site name and local
    level frame name based on it.
  */
  strcpy ( lsite, argv[2] );
  strcat ( lsite, "_landing_site" );
  strcpy ( frame, argv[2] );
  strcat ( frame, "_local_level" );

  /*
    Third argument is the time provided as a UTC string. Convert it to
    ET.
  */
  str2et_c( argv[3], &et );

  /*
    Fourth, fifth, and sixth argument are X, Y and Z of the rover position
    with respect to the landing site in local level frame in km.
  */
  prsdp_c( argv[4], &localpos[0] );
  prsdp_c( argv[5], &localpos[1] );
  prsdp_c( argv[6], &localpos[2] );

  /*
    Compute position of the landing site relative to Mars in Mars
    body-fixed frame (IAU_MARS).
  */
  spkpos_c( lsite, et, "IAU_MARS", "NONE", "MARS", sitepos, &lt );

  /*
    Compute rotation from local level frame to IAU_MARS frame.
  */
  pxform_c( frame, "IAU_MARS", et, mat );

  /*
    Rotate input local position to IAU_MARS frame.
  */
  mxv_c( mat, localpos, tmpvec );

  /*
    Add local rover location to the site location.
  */
  vadd_c( sitepos, tmpvec, roverpos );

  /*
    Convert rover position to areocentric r, lon, and lat.
  */
  reclat_c( roverpos, &r, &lon, &lat );

  /*
    Print r and lon/lat in degrees.
  */  
  printf ( "\n" );
  printf ( "   r = %12.6f (km)\n",  r );
  printf ( " lon = %12.6f (deg)\n", lon*dpr_c() );
  printf ( " lat = %12.6f (deg)\n", lat*dpr_c() );

  /*
    All done.
  */
  return(0);

}
